@@ -27,7 +27,7 @@
 #include <KConfigGroup>
 #include <KXmlGuiWindow>
 #include <KProcess>
-#include <KStatusBar>
+#include <QStatusBar>
 
 #include <QTreeWidgetItemIterator>
 #include <QTreeWidgetItem>
@@ -349,5 +349,5 @@ void Glossary::slotSelectGlossEntry( const QString &id )
     setCurrentItem( newItem );
 }
 
-#include "glossary.moc"
+
 // vim:ts=4:sw=4:et
